@@ -163,12 +163,18 @@ ggdotchart_core <- function(data, x, y, group = NULL,
   if(rotate & sorting == "descending") sorting <- "ascending"
   else if(rotate & sorting == "ascending") sorting <- "descending"
 
-  y.sort <- y
-  if(sorting == "descending") y.sort <- paste0("desc(", y, ")")
-  if(is.null(group))
-    data <- dplyr::arrange_(data, .dots = y.sort)
-  else if(group != 1)
-    data <- dplyr::arrange_(data, .dots = c(group, y.sort))
+  if(is.null(group)){
+    if(sorting == "descending")
+      data <- arrange(data, desc(!!sym(y)))
+    else
+      data <- arrange(data, !!sym(y))
+  }
+  else if(group != 1){
+    if(sorting == "descending")
+      data <- arrange(data, !!sym(group), desc(!!sym(y)))
+    else
+      data <- arrange(data, !!!syms(c(group, y)))
+  }
 
   data[, x] <- factor(data[, x], levels = unique(as.vector(data[, x])))
 
