@@ -10,4 +10,6 @@ dplyr::group_by
 #' @importFrom ggsignif geom_signif
 #' @export
 ggsignif::geom_signif
-
+#' @importFrom rstatix get_summary_stats
+#' @export
+rstatix::get_summary_stats
